
#include <windows.h>
#include <stdio.h>

HANDLE MyThreadHandle = NULL;
DWORD MyThreadId = 0;
bool MyThreadEnable = false;

void DebugMess(char *sMess)
{
	char sDbg[257];

	sprintf(sDbg, "PID=%04x,TID=%04x: %s\n", GetCurrentProcessId(), GetCurrentThreadId(), sMess);
	OutputDebugString(sDbg);
}

DWORD WINAPI ThreadFunction(void *unused)
{
	while (MyThreadEnable)
	{
		DebugMess("Thread running...");
		keybd_event(VK_SCROLL, 0, 0, 0); 
		Sleep(500);
		keybd_event(VK_SCROLL, 0, KEYEVENTF_KEYUP, 0);
		Sleep(500);
	}

	return 0;
}

void ThreadCreate(void)
{
	SECURITY_ATTRIBUTES saAttr;

	if (MyThreadHandle == NULL)
	{
		saAttr.nLength 				= sizeof(SECURITY_ATTRIBUTES);
		saAttr.bInheritHandle 		= true;
		saAttr.lpSecurityDescriptor = NULL;
	
		MyThreadHandle			= CreateThread					(
									&saAttr						,
									0							,
									ThreadFunction				,
									(LPVOID) NULL				,
									CREATE_SUSPENDED			,
									&MyThreadId					);
	
		if (MyThreadHandle != NULL)
		{
			MyThreadEnable = true;
		}
	}
	
	return;
}

__declspec(dllexport)
void ThreadDestroy(void)
{
	if (MyThreadHandle)
	{
		/* Exit from loop */
		MyThreadEnable = false;
		/* Wait thread exit */
		switch (WaitForSingleObject(MyThreadHandle, 5000))  
		{
			case    WAIT_OBJECT_0	:
			{
				DebugMess("Thread ended OK");
				break;
			}
			case    WAIT_TIMEOUT	:
			{
				DebugMess("WaitForSingleObject - timeout");
				TerminateThread(MyThreadHandle, 0);
				break;
			}			
			default					:
			{
				DebugMess("WaitForSingleObject - other");
				TerminateThread(MyThreadHandle, 0);
				break;
            }
		}
		
		keybd_event(VK_SCROLL, 0, KEYEVENTF_KEYUP, 0);

		CloseHandle(MyThreadHandle);
	    
		MyThreadHandle = NULL;
		MyThreadId = 0;
	}
}

void _DllTimerProcessAttach(void)
{
	DebugMess("Attaching to process...");
	ThreadCreate();	

	if (MyThreadHandle)
	{
		DebugMess("Thread resume...");
		ResumeThread(MyThreadHandle);
	}
	else
	{
		DebugMess("Thread creation failed");
	}	
}

void _DllTimerProcessDetach(void)
{
	DebugMess("Detaching from process...");
	//ThreadDestroy();
}

void _DllTimerThreadAttach(void)
{
}

void _DllTimerThreadDetach(void)
{
}


int WINAPI DllMain(HINSTANCE hinst, unsigned long reason, void* lpReserved)
{
	int						iDllProcess = 1;

	switch ( reason )
	{
		case    DLL_THREAD_ATTACH    	:
		{
			_DllTimerThreadAttach();
			iDllProcess = 1;
			break;
		}
		case    DLL_THREAD_DETACH   	:
		{
			_DllTimerThreadDetach();
			iDllProcess = 1;
			break;
		}

		case	DLL_PROCESS_ATTACH	:
		{
			_DllTimerProcessAttach();
			iDllProcess = 1;
			break;
		}
		case	DLL_PROCESS_DETACH	:
		{
			_DllTimerProcessDetach();
			iDllProcess = 1;
			break;
		}
	}
	return	( iDllProcess );
}
